#!/bin/sh
# usr/opt/wrdapp/contour2.5/test/test.sh -- run tdds test data sets
#
# Usage: test.sh [start [stop]]
#        test.sh [start [stop]] | tee test.out
#
#        where: start = starting test number
#                stop = ending test number (may be same as start)
#
# To use this script for another program in a different directory, globally
# change the program name (be sure to change both upper and lower case
# occurrences) and set the default value for the Stop variable as appropriate.
#
# History: 12/24/91, mblalock, initial coding
#          04/27/92, mygoze, restructuring
#          01/24/96, rsregan, modified for use with contour
#
# Variable definitions
# --------------------
#
  TOPDIR=..
  DATA=$TOPDIR/data
  PROG=$TOPDIR/bin/contour
  CHECK=$TOPDIR/test/check.sh
  CLEAN=$TOPDIR/test/clean.sh
#PRIOR 101 = postscript, 1100 = X11, 7586 = HPGL
#XGKS 1 = X11, 2 = CGM
  WSTYPE=101
  PROGNM=contour
  END=1
  DIVD=========================================

  exec 2>&1                                # stderr shows up in .out file

  Start=${1:-1}                            # by default, start at 1
  Stop=${2:-$END}                             # by default, stop at 1
  if [ $Start -lt 1 ] ; then Start=1 ; fi
  if [ $Stop -lt 1 ] ; then Stop=$END ; fi
  if [ $Start -gt $END -o $Stop -gt $END ]
  then
    echo
    echo "Warning, invalid arguments--test range is 1 - $END for $PROGNM"
    echo "input arguments were $Start - $Stop"
    echo
    if [ $Stop -gt $END ] ; then Stop=$END ; fi
    if [ $Start -gt $END ]
    then
      echo "no $PROGNM tests will be performed"
    else
      echo "Tests $Start - $Stop will be performed"
    fi
    echo
  fi

#
# begin test runs
#
  Test=$Start

  if [ $Test -ge $Start -a $Test -le $Stop ]
  then
    echo
    echo $DIVD$DIVD
    echo "Begin processing $PROGNM test runs $Start to $Stop"
    echo
    date
  fi
#
# remove old output file
$CLEAN
#
# begin test runs
#
  while [ $Test -ge $Start -a $Test -le $Stop ]
  do
    echo
    echo
    echo $DIVD$DIVD
    echo "Test run number $Test"
    rm -f go
    echo 18,18 > go
    echo $DATA/delx.dat >> go
    echo "(10F6.0)" >> go
    echo 1,1 >> go
    echo $DATA/dely.dat >> go
    echo "(10F6.0)" >> go
    echo 1,1 >> go
    echo Y >> go
    echo N >> go
    echo 24000 >> go
    echo Y >> go
    echo $DATA/z.dat >> go
    echo "(10F8.0)" >> go
    echo 1,1 >> go
    echo N >> go
    echo 5 >> go
    echo 1,2,3,4,5 >> go
    echo Y >> go
    echo N >> go
    echo CONTOUR Test >> go
    echo $WSTYPE >> go
    echo " " >> go
    Name=$PROGNM$Test
    $PROG < go > $Name.log
    Test=`expr $Test + 1`
  done
  Test=`expr $Test - 1`
#
  if [ $Test -ge $Start -a $Test -le $Stop ]
  then
    echo
    echo
    echo $DIVD$DIVD
    echo "Completed $PROGNM test runs $Start to $Test"
    echo
  fi

# check output against original output in $DATA directory
  $CHECK contour GKS
